/**
 * Copyright 2019, Optimizely
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { DatafileManager, DatafileManagerConfig, DatafileUpdate } from './datafileManager';
import { AbortableRequest, Headers } from './http';
export default abstract class HTTPPollingDatafileManager implements DatafileManager {
    protected abstract makeGetRequest(reqUrl: string, headers: Headers): AbortableRequest;
    protected abstract getConfigDefaults(): Partial<DatafileManagerConfig>;
    private currentDatafile;
    private readonly sdkKey;
    private readonly readyPromise;
    private isReadyPromiseSettled;
    private readyPromiseResolver;
    private readyPromiseRejecter;
    private readonly emitter;
    private readonly autoUpdate;
    private readonly updateInterval;
    private cancelTimeout?;
    private isStarted;
    private lastResponseLastModified?;
    private urlTemplate;
    private timeoutFactory;
    private currentRequest?;
    private backoffController;
    constructor(config: DatafileManagerConfig);
    get(): object | null;
    start(): void;
    stop(): Promise<void>;
    onReady(): Promise<void>;
    on(eventName: string, listener: (datafileUpdate: DatafileUpdate) => void): import("./eventEmitter").Disposer;
    private getUrl;
    private onRequestRejected;
    private onRequestResolved;
    private onRequestComplete;
    private syncDatafile;
    private resolveReadyPromise;
    private rejectReadyPromise;
    private scheduleNextUpdate;
    private getNextDatafileFromResponse;
    private tryParsingBodyAsJSON;
    private trySavingLastModified;
}
